"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.OdfElement = void 0;
/**
 * Base element in Open Document Format
 * @since 0.1.0
 * @private
 */
class OdfElement {
    /**
     * Constructor.
     * @since 0.1.0
     */
    constructor() {
        this.children = [];
    }
    /**
     * Returns all child elements.
     *
     * @returns {OdfElement[]} A copy of the list of child elements
     * @since 0.2.0
     */
    getAll() {
        return Array.from(this.children);
    }
    /**
     * Appends the element as a child element to this element.
     *
     * @param {OdfElement} element The element to append
     * @since 0.1.0
     */
    append(element) {
        this.children.push(element);
    }
    /**
     * Inserts the element at the specified position in the list of child elements.
     *
     * @param {number} position The index at which to insert the element (starting from 0).
     * If greater than the number child elements, the element will appended at the end of the list.
     * If negative, the element will be inserted as first element.
     * @param {OdfElement} element The element to insert
     * @since 0.2.0
     */
    insert(position, element) {
        let index = position;
        if (position < 0) {
            index = 0;
        }
        else if (position > this.children.length) {
            index = this.children.length;
        }
        this.children.splice(index, 0, element);
    }
    /**
     * Returns the element at the specified position.
     *
     * @param {number} position The index of the requested the element (starting from 0).
     * @returns {OdfElement | undefined} The element at the specified position
     * or undefined if there is no element at the specified position
     * @since 0.2.0
     */
    get(position) {
        if (position < 0) {
            return undefined;
        }
        if (position > this.children.length) {
            return undefined;
        }
        return this.children[position];
    }
    /**
     * Removes the child element from the specified position.
     *
     * @param {number} position The index of the element to remove (starting from 0).
     * @returns {OdfElement | undefined} The removed child element
     * or undefined if there is no element at the specified position
     * @since 0.2.0
     */
    removeAt(position) {
        const oldElement = this.get(position);
        if (oldElement !== undefined) {
            this.children.splice(position, 1);
        }
        return oldElement;
    }
    /**
     * Returns whether the element has any child elements.
     *
     * @returns {boolean} TRUE if the there is any child element, FALSE otherwise
     * @since 0.2.0
     */
    hasChildren() {
        return this.children.length > 0;
    }
}
exports.OdfElement = OdfElement;
