import { OdfElement } from '../OdfElement';
import { AnchorType } from './AnchorType';
/**
 * This class represents an image in a paragraph.
 *
 * It is used to embed image data in BASE64 encoding.
 *
 * @example
 * document.getBody()
 *   .addParagraph()
 *   .addImage('/home/homer/myself.png')
 *   .setAnchorType(AnchorType.AsChar);
 *   .setSize(42, 23);
 *
 * @since 0.3.0
 */
export declare class Image extends OdfElement {
    private path;
    private anchorType;
    private height;
    private width;
    /**
     * Creates an image
     *
     * @example
     * const image = new Image('/home/homer/myself.png');
     *
     * @param {string} path Path to the image file that should be embedded
     * @since 0.3.0
     */
    constructor(path: string);
    /**
     * The `setAnchorType()` method sets the anchor type setting of this image.
     *
     * @example
     * const image = new Image('/home/homer/myself.png');
     * image.setAnchorType(AnchorType.AsChar);
     *
     * @param {AnchorType} anchorType The anchor type setting
     * @returns {Image} The `Image` object
     * @since 0.9.0
     */
    setAnchorType(anchorType: AnchorType): Image;
    /**
     * The `getAnchorType()` method returns the anchor type setting of this image.
     *
     * @example
     * const image = new Image('/home/homer/myself.png');
     * image.getAnchorType();                  // AnchorType.Paragraph
     * image.setAnchorType(AnchorType.AsChar);
     * image.getAnchorType();                  // AnchorType.AsChar
     *
     * @returns {AnchorType} The anchor type setting
     * @since 0.9.0
     */
    getAnchorType(): AnchorType;
    /**
     * The `setHeight` method sets the target height of the image in millimeter.
     *
     * If the provided value is too small, the height will be set to the minimal size `1`.
     *
     * @example
     * const image = new Image('/home/homer/myself.png');
     * image.setHeight(42);  // 42
     * image.setHeight(-23); // 1
     *
     * @param {number} height The target height of the image in millimeter
     * @returns {Image} The `Image` object
     * @since 0.9.0
     */
    setHeight(height: number): Image;
    /**
     * The `getHeight()` method returns the target height of the image or `undefined` if no height was set.
     *
     * @example
     * const image = new Image('/home/homer/myself.png');
     * image.getHeight();   // undefined
     * image.setHeight(42);
     * image.getHeight();   // 42
     *
     * @returns {number | undefined} The target height of the image in millimeter or `undefined` if no height was set
     * @since 0.9.0
     */
    getHeight(): number | undefined;
    /**
     * The `getPath()` method returns the path to the image file that should be embedded.
     *
     * @example
     * const image = new Image('/home/homer/myself.png');
     * image.getPath(); // '/home/homer/myself.png'
     *
     * @returns {string} The path to the image file
     * @since 0.7.0
     */
    getPath(): string;
    /**
     * The `setSize()` method sets the target width and height of the image.
     *
     * If any provided value is too small, it will be set to the minimal size `1`.
     *
     * @example
     * const image = new Image('/home/homer/myself.png');
     * image.setSize(42, 23);   // w:42, h:32
     * image.setWidth(42, -23); // w:42, h:1
     *
     * @param {number} width The target width of the image in millimeter
     * @param {number} height The target height of the image in millimeter
     * @returns {Image} The `Image` object
     * @since 0.9.0
     */
    setSize(width: number, height: number): Image;
    /**
     * The `setWidth` method sets the target width of the image in millimeter.
     *
     * If the provided value is too small, the width will be set to the minimal size `1`.
     *
     * @example
     * const image = new Image('/home/homer/myself.png');
     * image.setWidth(42);  // 42
     * image.setWidth(-23); // 1
     *
     * @param {number} width The target width of the image in millimeter
     * @returns {Image} The `Image` object
     * @since 0.9.0
     */
    setWidth(width: number): Image;
    /**
     * The `getWidth()` method returns the target width of the image or `undefined` if no width was set.
     *
     * @example
     * const image = new Image('/home/homer/myself.png');
     * image.getWidth();   // undefined
     * image.setWidth(42);
     * image.getWidth();   // 42
     *
     * @returns {number | undefined} The target width of the image in millimeter or `undefined` if no width was set
     * @since 0.9.0
     */
    getWidth(): number | undefined;
}
