"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BulletListLevelStyle = void 0;
const util_1 = require("../util");
const ListLevelProperties_1 = require("./ListLevelProperties");
const DEFAULT_BULLET_CHAR = '\u2022';
/**
 * This class represents a list style where list items are preceded by bullets.
 *
 * @example
 * document.getStyleManager()
 *   .createListStyle('Contents')
 *   .createBulletListLevelStyle(3);
 *
 * @since 0.11.0
 */
class BulletListLevelStyle {
    /**
     * Creates a `BulletListLevelStyle` instance that represents a list style where list items are preceded by bullets.
     *
     * @example
     * const style = new BulletListLevelStyle(3);
     *
     * @param {number} level The level of the list style, starting with `1`
     *
     * @since 0.11.0
     */
    constructor(level) {
        this.bulletChar = DEFAULT_BULLET_CHAR;
        this.level = level;
        this.listLevelProperties = new ListLevelProperties_1.ListLevelProperties();
    }
    /**
     * The `getBulletChar()` method returns the character to use as the bullet.
     *
     * @example
     * const style = new BulletListLevelStyle(3);
     * style.getBulletChar();    // '\u2022'
     * style.setBulletChar('~');
     * style.getBulletChar();    // '~'
     *
     * @returns {string} The character to use as the bullet
     * @since 0.11.0
     */
    getBulletChar() {
        return this.bulletChar;
    }
    /**
     * The `setBulletChar()` method sets the character to use as the bullet.
     *
     * If an illegal value is provided, the value will be ignored.
     *
     * @example
     * const style = new BulletListLevelStyle(3);
     * style.setBulletChar('~'); // '~'
     * style.setBulletChar('');  // '~'
     *
     * @param {string} bulletChar The character to use as the bullet
     * @returns {BulletListLevelStyle} The `BulletListLevelStyle` object
     * @since 0.11.0
     */
    setBulletChar(bulletChar) {
        this.bulletChar = bulletChar.trim().charAt(0) || this.bulletChar;
        return this;
    }
    /**
     * The `getLevel()` method returns the level of the list style.
     *
     * @example
     * const style = new BulletListLevelStyle(3);
     * style.getLevel(); // 3
     *
     * @returns {number} The level of the list style, starting with `1`
     * @since 0.11.0
     */
    getLevel() {
        return this.level;
    }
    /**
     * The `getNumberPrefix()` method returns the character to display before a bullet.
     *
     * @example
     * const style = new BulletListLevelStyle(3);
     * style.getNumberPrefix();    // undefined
     * style.setNumberPrefix('~');
     * style.getNumberPrefix();    // '~'
     *
     * @returns {string | undefined} The character to display before a bullet or `undefined` if no prefix is set
     * @since 0.11.0
     */
    getNumberPrefix() {
        return this.numPrefix;
    }
    /**
     * The `setNumberPrefix()` method sets the character to display before a bullet.
     *
     * @example
     * const style = new BulletListLevelStyle(3);
     * style.setNumberPrefix('~');       // '~'
     * style.setNumberPrefix(undefined); // undefined
     *
     * @param {string | undefined} prefix The character to display before a bullet or `undefined` to unset the prefix
     * @returns {BulletListLevelStyle} The `BulletListLevelStyle` object
     * @since 0.11.0
     */
    setNumberPrefix(prefix) {
        this.numPrefix = prefix;
        return this;
    }
    /**
     * The `getNumberSuffix()` method returns the character to display after a bullet.
     *
     * @example
     * const style = new BulletListLevelStyle(3);
     * style.getNumberSuffix();    // undefined
     * style.setNumberSuffix('~');
     * style.getNumberSuffix();    // '~'
     *
     * @returns {string | undefined} The character to display after a bullet or `undefined` if no suffix is set
     * @since 0.11.0
     */
    getNumberSuffix() {
        return this.numSuffix;
    }
    /**
     * The `setNumberSuffix()` method sets the character to display after a bullet.
     *
     * @example
     * const style = new BulletListLevelStyle(3);
     * style.setNumberSuffix('~');       // '~'
     * style.setNumberSuffix(undefined); // undefined
     *
     * @param {string | undefined} suffix The character to display after a bullet or `undefined` to unset the suffix
     * @returns {BulletListLevelStyle} The `BulletListLevelStyle` object
     * @since 0.11.0
     */
    setNumberSuffix(suffix) {
        this.numSuffix = suffix;
        return this;
    }
    /**
     * The `getRelativeBulletSize()` method returns the percentage value for the bullet size relative to the font size of the paragraphs in the bullet list.
     *
     * @example
     * const style = new BulletListLevelStyle(3);
     * style.getRelativeBulletSize();      // undefined
     * style.setRelativeBulletSize('23%');
     * style.getRelativeBulletSize();      // '23%'
     *
     * @returns {string | undefined} The percentage value for the bullet size or `undefined` if no relative bullet size is set
     * @since 0.11.0
     */
    getRelativeBulletSize() {
        return this.bulletRelativeSize;
    }
    /**
     * The `setNumberSuffix()` method sets the percentage value for the bullet size relative to the font size of the paragraphs in the bullet list.
     *
     * If an illegal value is provided, the value will be ignored.
     *
     * @example
     * const style = new BulletListLevelStyle(3);
     * style.setRelativeBulletSize('23%');     // '23%'
     * style.setRelativeBulletSize('42px');    // '23%'
     * style.setRelativeBulletSize(undefined); // undefined
     *
     * @param {string | undefined} relativeSize The percentage value for the bullet size or `undefined` to unset the bullet size
     * @returns {BulletListLevelStyle} The `BulletListLevelStyle` object
     * @since 0.11.0
     */
    setRelativeBulletSize(relativeSize) {
        if (relativeSize === undefined || (0, util_1.isPercent)(relativeSize)) {
            this.bulletRelativeSize = relativeSize;
        }
        return this;
    }
    // ListLevelProperties
    /** @inheritdoc */
    /* istanbul ignore next */
    getListLevelPositionAndSpaceMode() {
        return this.listLevelProperties.getListLevelPositionAndSpaceMode();
    }
    /** @inheritdoc */
    /* istanbul ignore next */
    getLabelFollowedBy() {
        return this.listLevelProperties.getLabelFollowedBy();
    }
    /** @inheritdoc */
    /* istanbul ignore next */
    setLabelFollowedBy(value) {
        this.listLevelProperties.setLabelFollowedBy(value);
        return this;
    }
    /** @inheritdoc */
    /* istanbul ignore next */
    getListTabStopPosition() {
        return this.listLevelProperties.getListTabStopPosition();
    }
    /** @inheritdoc */
    /* istanbul ignore next */
    setListTabStopPosition(position) {
        this.listLevelProperties.setListTabStopPosition(position);
        return this;
    }
    /** @inheritdoc */
    /* istanbul ignore next */
    getTextIndent() {
        return this.listLevelProperties.getTextIndent();
    }
    /** @inheritdoc */
    /* istanbul ignore next */
    setTextIndent(indent) {
        this.listLevelProperties.setTextIndent(indent);
        return this;
    }
    /** @inheritdoc */
    /* istanbul ignore next */
    getMarginLeft() {
        return this.listLevelProperties.getMarginLeft();
    }
    /** @inheritdoc */
    /* istanbul ignore next */
    setMarginLeft(margin) {
        this.listLevelProperties.setMarginLeft(margin);
        return this;
    }
}
exports.BulletListLevelStyle = BulletListLevelStyle;
/*
<element name="text:list-level-style-bullet">
  <ref name="text-list-level-style-attr"/><!-- DONE -->
  <ref name="text-list-level-style-bullet-attr"/><!-- PARTIALLY DONE -->
  <optional>
    <ref name="style-list-level-properties"/><!-- DONE -->
  </optional>
  <optional>
    <ref name="style-text-properties"/><!-- for number and bullet only -->
  </optional>
</element>

<define name="text-list-level-style-bullet-attr">
  <interleave>
    <optional>
      <attribute name="text:style-name">
        <ref name="styleNameRef"/>
      </attribute>
    </optional>
    <attribute name="text:bullet-char"><!-- DONE -->
      <ref name="character"/>
    </attribute>
    <ref name="common-num-format-prefix-suffix-attlist"/><!-- DONE -->
    <optional>
      <attribute name="text:bullet-relative-size"><!-- DONE -->
        <ref name="percent"/>
      </attribute>
    </optional>
  </interleave>
</define>
*/
