"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.OdfTextElementWriter = void 0;
const TextElementName_1 = require("./TextElementName");
const CARRIAGE_RETURN = '\r';
const LINE_FEED = '\n';
const SPACE = ' ';
const TAB = '\t';
class OdfTextElementWriter {
    /**
     * @inheritdoc
     * @since 0.7.0
     */
    write(odfText, document, parent) {
        const text = odfText.getText();
        if (text === undefined || text === '') {
            return;
        }
        let str = '';
        for (let index = 0; index < text.length; index++) {
            const currentChar = text.charAt(index);
            switch (currentChar) {
                case SPACE:
                    str += currentChar;
                    const count = this.findNextNonSpaceCharacter(text, index) - 1; // eslint-disable-line no-case-declarations
                    if (count > 0) {
                        this.appendTextNode(document, parent, str);
                        this.appendSpaceNode(document, parent, count);
                        str = '';
                        index += count;
                    }
                    break;
                case LINE_FEED:
                    this.appendTextNode(document, parent, str);
                    this.appendLineBreakNode(document, parent);
                    str = '';
                    break;
                case TAB:
                    this.appendTextNode(document, parent, str);
                    this.appendTabNode(document, parent);
                    str = '';
                    break;
                case CARRIAGE_RETURN:
                    break;
                default:
                    str += currentChar;
                    break;
            }
        }
        this.appendTextNode(document, parent, str);
    }
    /**
     * Creates a text node with the provided text and appends it to the parent element.
     *
     * @param {Document} document The XML document
     * @param {Element} parent The parent node
     * @param {string} text The text value of the text node
     * @since 0.3.0
     */
    appendTextNode(document, parent, text) {
        if (text.length === 0) {
            return;
        }
        const textNode = document.createTextNode(text);
        parent.appendChild(textNode);
    }
    /**
     * Creates a space node representing the specified number of space characters and appends it to the parent element.
     * If a single space character should be represented, the `c` attribute is omitted.
     *
     * @param {Document} document The XML document
     * @param {Element} parent The parent node
     * @param {number} count The number of space characters the node should represent
     * @since 0.3.0
     */
    appendSpaceNode(document, parent, count) {
        const space = document.createElement(TextElementName_1.TextElementName.TextSpace);
        parent.appendChild(space);
        if (count > 1) {
            space.setAttribute('c', count.toString(10));
        }
    }
    /**
     * Creates a tabulation node and appends it to the parent element.
     *
     * @param {Document} document The XML document
     * @param {Element} parent The parent node
     * @since 0.3.0
     */
    appendTabNode(document, parent) {
        const tabulation = document.createElement(TextElementName_1.TextElementName.TextTabulation);
        parent.appendChild(tabulation);
    }
    /**
     * Creates a line break node and appends it to the parent element.
     *
     * @param {Document} document The XML document
     * @param {Element} parent The parent node
     * @since 0.3.0
     */
    appendLineBreakNode(document, parent) {
        const lineBreak = document.createElement(TextElementName_1.TextElementName.TextLineBreak);
        parent.appendChild(lineBreak);
    }
    /**
     * Finds the next non-space character and returns the number of space characters that occur before.
     *
     * @param {string} text The text to search in
     * @param {number} offset The index at which to start the search
     * @returns {number} The number of space characters before the next non-space character
     * @since 0.3.0
     */
    findNextNonSpaceCharacter(text, offset) {
        for (let index = offset; index < text.length; index++) {
            if (text.charAt(index) !== SPACE) {
                return index - offset;
            }
        }
        return text.length - offset;
    }
}
exports.OdfTextElementWriter = OdfTextElementWriter;
